@@ -36,10 +36,11 @@ def getDefaultSite():
 	return hubzero.config.hubzerositeconfig.getHubzeroConfigOption("DEFAULT", "site")
 	
 
-def getWebConfigOption(optionName):
+def getWebConfigOption(optionName, hubName = ""):
 	
-	defaultSite = getDefaultSite()
-	wwwDocRoot = hubzero.config.hubzerositeconfig.getHubzeroConfigOption(defaultSite, "DocumentRoot")	
+	if not hubName: hubName = getDefaultSite()
+
+	wwwDocRoot = hubzero.config.hubzerositeconfig.getHubzeroConfigOption(hubName, "DocumentRoot")	
 	
 	# read config values from file
 	file = open(wwwDocRoot + "/configuration.php")
@@ -64,27 +65,48 @@ def getWebConfigOption(optionName):
 		return ""
 		    
 
-def getWebConfigDBPassword():
-	return getWebConfigOption("password")
+def getWebConfigDBPassword(hubName = ""):
+	"""
+	If hubName is not specified, getWebConfigOption returns value for the default hubName
+	"""
+
+	if not hubName:
+		return getWebConfigOption("password")
+	else:
+		return getWebConfigOption("password", hubName)
 
 
-def getWebConfigDBUsername():
-	return getWebConfigOption("user")
+def getWebConfigDBUsername(hubName = ""):
+	"""
+	If hubName is not specified, getWebConfigOption returns value for the default hubName
+	"""
+
+	if not hubName: 
+		return getWebConfigOption("user")
+	else
+		return getWebConfigOption("user",  hubName)
 
 
-def getWebConfigDBName():
-	return getWebConfigOption("db")
+def getWebConfigDBName(hubName = ""):
+	"""
+	If hubName is not specified, getWebConfigOption returns value for the default hubName
+	"""
+
+	if not hubName: 
+		return getWebConfigOption("db")
+	else:
+		return getWebConfigOption("db", hubName)
 
 
-def _writeParamField(componentOption, NewParamValueDictionary):
+def _writeParamField(componentOption, NewParamValueDictionary, hubName):
 	"""
 	Take a dictionary, transform it to properly formatted params string for Joomla, and 
 	update the params field of the jos_components table for the specified component
 	"""
 	# database config
-	dbPW = getWebConfigDBPassword()
-	dbUserName = getWebConfigDBUsername()
-	dbName = getWebConfigDBName()	
+	dbPW = getWebConfigDBPassword(hubName)
+	dbUserName = getWebConfigDBUsername(hubName)
+	dbName = getWebConfigDBName(hubName)	
 	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
 
 	parmString = ""
@@ -96,7 +118,7 @@ def _writeParamField(componentOption, NewParamValueDictionary):
 	db.query_rowcount(sql, data)
 
 
-def _buildDictionary(componentOption):
+def _buildDictionary(componentOption, hubName):
 	"""
 	Put the parameter string of the database into a dictionary
 	String follows the format:
@@ -107,9 +129,9 @@ def _buildDictionary(componentOption):
 	
 	"""
 	# database config
-	dbPW = getWebConfigDBPassword()
-	dbUserName = getWebConfigDBUsername()
-	dbName = getWebConfigDBName()	
+	dbPW = getWebConfigDBPassword(hubName)
+	dbUserName = getWebConfigDBUsername(hubName)
+	dbName = getWebConfigDBName(hubName)	
 	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
 	
 	# look up parm string and parse it on newline, for each line, parse it further based on *first* '='
@@ -127,11 +149,11 @@ def _buildDictionary(componentOption):
 	return parmsDict
 	
 
-def getComponentParam(componentOption, parameterName):
+def getComponentParam(componentOption, parameterName, hubName = ""):
 	"""
 	Get individual param value for a component and return to caller
 	"""
-	paramDict = _buildDictionary(componentOption)
+	paramDict = _buildDictionary(componentOption, hubName)
 	
 	if paramDict.has_key(parameterName):
 		return paramDict[parameterName]
@@ -139,11 +161,11 @@ def getComponentParam(componentOption, parameterName):
 		return None	
 
 
-def addComponentParam(componentOption, parameterName, parameterValue, allowOverwrite=True):
+def addComponentParam(componentOption, parameterName, parameterValue, allowOverwrite=True, hubName = ""):
 	"""
 	Add value to the param string in the jos_components table for the specified component.
 	"""
-	paramDict = _buildDictionary(componentOption)
+	paramDict = _buildDictionary(componentOption, hubName)
 
 	if allowOverwrite:
 		paramDict[parameterName] = parameterValue
@@ -156,24 +178,24 @@ def addComponentParam(componentOption, parameterName, parameterValue, allowOverw
 	_writeParamField(componentOption, paramDict)	
 
 	
-def delComponentParam(componentOption, parameterName):
+def delComponentParam(componentOption, parameterName, hubName = ""):
 	"""
 	Delete value from the param string in the in the jos_components table for the specified component
 	"""
-	paramDict = _buildDictionary(componentOption)
+	paramDict = _buildDictionary(componentOption, hubName)
 	del paramDict[parameterName]
-	_writeParamField(componentOption, paramDict)
+	_writeParamField(componentOption, paramDict, hubName)
 	
 	
-def setPluginEnabled(pluginFolder, pluginElement, enable):
+def setPluginEnabled(pluginFolder, pluginElement, enable, hubName = ""):
 	"""
 	Enable or disable a plugin by setting the published field for the plugin in the jos_plugins table
 	"""
 	
 	# database config
-	dbPW = getWebConfigDBPassword()
-	dbUserName = getWebConfigDBUsername()
-	dbName = getWebConfigDBName()	
+	dbPW = getWebConfigDBPassword(hubName)
+	dbUserName = getWebConfigDBUsername(hubName)
+	dbName = getWebConfigDBName(hubName)	
 	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
 		
 	sql = "UPDATE jos_plugins set published = %s WHERE `folder` = %s AND `element` = %s"
